---
title: utils
sidebarTitle: utils
---

# `catalax.model.utils`

## Functions

### `odeprint` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/utils.py#L47" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
odeprint(y, expr)
```


Displays an ODE with a left-hand side derivative


### `eqprint` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/utils.py#L59" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
eqprint(y, expr)
```


Displays an ODE with a left-hand side derivative


### `parameter_exists` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/utils.py#L71" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
parameter_exists(name: str, parameters: Dict[str, Parameter]) -> bool
```


Checks whether a parameter is already present in a model


### `check_symbol` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/utils.py#L77" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
check_symbol(symbol: str) -> None
```


Checks whether the given symbol is a valid symbol


## Classes

### `PrettyDict` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/utils.py#L12" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>
